"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const common_1 = require("@graphql-cli/common");
const loaders_1 = require("@graphql-cli/loaders");
const coverage_command_1 = tslib_1.__importDefault(require("@graphql-inspector/coverage-command"));
const loaders_2 = require("@graphql-inspector/loaders");
exports.default = common_1.defineCommand((api) => {
    const loadersRegistry = new loaders_2.LoadersRegistry();
    loaders_1.loaders.forEach((loader) => loadersRegistry.register(loader));
    return coverage_command_1.default({
        config: {
            loaders: [],
            commands: [],
        },
        loaders: loadersRegistry,
        interceptPositional(key, opt) {
            if (key === 'schema') {
                opt.demandOption = false;
            }
            if (key === 'documents') {
                opt.demandOption = false;
            }
            return opt;
        },
        interceptOptions(opts) {
            return {
                ...opts,
                project: {
                    type: 'string',
                    describe: 'Name of a project from GraphQL Config',
                },
                config: {
                    type: 'string',
                    describe: 'Location of GraphQL Config',
                },
            };
        },
        async interceptArguments(args) {
            if (typeof args.schema === 'undefined') {
                const config = await api.useConfig({
                    rootDir: args.config || process.cwd(),
                });
                const project = args.project ? config.getProject(args.project) : config.getDefault();
                args.schema = project.schema;
                args.documents = project.documents;
            }
        },
    });
});
//# sourceMappingURL=index.js.map