import { defineCommand } from '@graphql-cli/common';
import { loaders } from '@graphql-cli/loaders';
import coverage from '@graphql-inspector/coverage-command';
import { LoadersRegistry } from '@graphql-inspector/loaders';

export default defineCommand((api) => {
  const loadersRegistry = new LoadersRegistry();

  loaders.forEach((loader) => loadersRegistry.register(loader));

  return coverage({
    config: {
      loaders: [],
      commands: [],
    },
    loaders: loadersRegistry,
    interceptPositional(key, opt) {
      if (key === 'schema') {
        opt.demandOption = false;
      }

      if (key === 'documents') {
        opt.demandOption = false;
      }

      return opt;
    },
    interceptOptions(opts) {
      return {
        ...opts,
        project: {
          type: 'string',
          describe: 'Name of a project from GraphQL Config',
        },
        config: {
          type: 'string',
          describe: 'Location of GraphQL Config',
        },
      };
    },
    async interceptArguments(args) {
      if (typeof args.schema === 'undefined') {
        const config = await api.useConfig({
          rootDir: args.config || process.cwd(),
        });
        const project = args.project ? config.getProject(args.project) : config.getDefault();

        (args as any).schema = project.schema;
        (args as any).documents = project.documents;
      }
    },
  });
});
